<script setup lang="ts">
import { ElLoading, FormInstance } from "element-plus";
import UserApi, { UserInfo } from "@/api/user";
import { sexList, roleList } from "@/assets/const/const_user";
import { useUserStore } from "@/store";

const { userInfo } = useUserStore();

const props = defineProps(["data"]);
const emit = defineEmits(["update:close", "success"]);
const formRef = ref();
const paramsRef = ref<UserInfo>({
  id: 0,
  name: "",
  pwd: "123456",
  sex: 1,
  roleId: 1,
  email: "496960745@qq.com",
  phoneNumber: "18171444936",
  createTime: "2025-04-25 00:00:00",
  roles: [],
  perms: [],
});
const rulesRef = ref({
  phoneNumber: [
    { required: true, message: "请输入手机号", trigger: "blur" },
    {
      pattern: /^1[3|4|5|6|7|8|9][0-9]\d{8}$/,
      message: "请输入正确的手机号码",
      trigger: "blur",
    },
  ],
  email: [
    { required: true, message: "请输入邮箱地址", trigger: "blur" },
    {
      pattern: /\w[-\w.+]*@([A-Za-z0-9][-A-Za-z0-9]+\.)+[A-Za-z]{2,14}/,
      message: "请输入正确的邮箱地址",
      trigger: "blur",
    },
  ],
  name: [{ required: true, message: "请输入用户名称", trigger: "blur" }],
  pwd: [{ required: true, message: "请输入密码", trigger: "blur" }],
});
const layout = reactive({
  gutter: 16,
  span: 24,
});

// 提交表单
function submitForm(formEl: FormInstance) {
  if (!formEl) return;
  formEl.validate((valid, fields) => {
    if (valid) {
      editUser();
    } else {
      ElMessage({
        message: "存在不合法数据，请修改！！！",
        type: "warning",
      });
      console.log("error submit!", fields);
    }
  });
}

function editUser() {
  const loading = ElLoading.service({
    lock: true,
    text: "设置中...",
    background: "rgba(0, 0, 0, 0.7)",
  });
  const params = JSON.parse(JSON.stringify(paramsRef.value));
  UserApi.edit(params)
    .then((res) => {
      if (res.code === 1) {
        ElMessage({
          message: "修改成功！！！",
          type: "success",
        });
        emit("success", true);
        emit("update:close", false);
      } else {
        ElMessage({
          message: "修改失败！！！",
          type: "warning",
        });
      }
    })
    .catch((error) => {
      console.log(error);
      ElMessage({
        message: "接口请求失败，请联系管理员！！！",
        type: "error",
      });
    })
    .finally(() => {
      loading.close();
    });
}

function close() {
  emit("update:close", false);
}

onMounted(() => {
  paramsRef.value = JSON.parse(JSON.stringify(props.data));
});
</script>

<template>
  <div class="dialog-wrapper">
    <el-form
      ref="formRef"
      label-position="top"
      :model="paramsRef"
      :rules="rulesRef"
      label-width="auto"
    >
      <el-row :gutter="layout.gutter">
        <el-col :span="layout.span">
          <el-form-item label="用户名称" prop="name">
            <el-input v-model="paramsRef.name"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="性别" prop="sex">
            <el-select v-model="paramsRef.sex">
              <el-option
                v-for="item in sexList"
                :key="item.value"
                :label="item.label"
                :value="item.value"
              ></el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="角色" prop="roleId">
            <el-select v-model="paramsRef.roleId" :disabled="userInfo.name === paramsRef.name">
              <el-option
                v-for="item in roleList"
                :key="item.value"
                :label="item.label"
                :value="item.value"
              ></el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="layout.span">
          <el-form-item label="邮箱" prop="email">
            <el-input v-model="paramsRef.email"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="layout.span">
          <el-form-item label="电话号码" prop="phoneNumber">
            <el-input v-model="paramsRef.phoneNumber"></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <div class="from-footer">
        <el-button type="primary" @click="submitForm(formRef)">确定</el-button>
        <el-button type="danger" @click="close">取消</el-button>
      </div>
    </el-form>
  </div>
</template>

<style scoped lang="scss">
.dialog-wrapper {
  width: 580px;
  .from-footer {
    text-align: right;
  }
}
</style>
